@@ -70,6 +70,7 @@ err_code_struct dos_msgs[] = {
   {"ERRpipeclosing",232,"Pipe close in progress."},
   {"ERRnotconnected",233,"No process on other end of pipe."},
   {"ERRmoredata",234,"There is more data to be returned."},
+  {"ERRinvapi", 2142, "The API is invalid."},
   {NULL,-1,NULL}};
 
 /* Server Error Messages */
@@ -105,6 +106,7 @@ err_code_struct server_msgs[] = {
   {"ERRcontmpx",252,"Continue in MPX mode."},
   {"ERRreserved",253,"reserved."},
   {"ERRreserved",254,"reserved."},
+  {"ERRpwdexp",2242,"Password has expired."},
   {"ERRnosupport",0xFFFF,"Function not supported."},
   {NULL,-1,NULL}};
 
