@@ -82,6 +82,24 @@ SMB_Handle_Type SMB_Create_Con_Handle()
 
 }
 
+int SMBlib_Set_Sock_NoDelay(SMB_Handle_Type Con_Handle, BOOL yn)
+
+{
+
+
+  if (RFCNB_Set_Sock_NoDelay(Con_Handle -> Trans_Connect, yn) < 0) {
+
+#ifdef DEBUG
+#endif
+
+    fprintf(stderr, "Setting no-delay on TCP socket failed ...\n");
+
+  }
+
+  return(0);
+
+}
+
 /* SMB_Connect_Server: Connect to a server, but don't negotiate protocol */
 /* or anything else ...                                                  */
 
@@ -167,15 +185,6 @@ SMB_Handle_Type SMB_Connect_Server(SMB_Handle_Type Con_Handle,
 
   }
 
-/*  if (RFCNB_Set_Sock_Delay(con -> Trans_Connect, TRUE) < 0) {
-
-#ifdef DEBUG
-#endif
-
-    fprintf(stderr, "Setting no-delay on TCP socket failed ...\n");
-
-  } */
-
   return(con);
 
 }
@@ -466,7 +475,7 @@ int SMB_Logon_Server(SMB_Handle_Type Con_Handle, char *UserName,
   if (RFCNB_Send(Con_Handle -> Trans_Connect, pkt, pkt_len) < 0){
 
 #ifdef DEBUG
-    fprintf(stderr, "Error sending TCon request\n");
+    fprintf(stderr, "Error sending SessSetupX request\n");
 #endif
 
     RFCNB_Free_Pkt(pkt);
