@@ -27,7 +27,7 @@
    -r sets the repeat count
    -s sets the file service to try against
    -w means check write perf. Read is the default.
-
+   -n means set TCP_NODELAY on socket ...
 */
 
 #include <sys/types.h>
@@ -42,9 +42,10 @@
 #define TEST_FILE_SERVICE "msfax"
 #define TEST_WRITE_SIZE 4096
 
-int verbose    = FALSE;
-int logon      = FALSE;
-int test_write = FALSE;
+int verbose         = FALSE;
+int logon           = FALSE;
+int test_write      = FALSE;
+int tcp_nodelay     = FALSE;
 int total_file_size = 10 * 1024 * 1024;
 
 char username[80] = "", password[80] = "", file_service[128] = "";
@@ -61,7 +62,7 @@ void usage()
 
   fprintf(stderr, "test_perf -l -v -u <username> -p <password> -r <count> -s");
   fprintf(stderr, " <file-service> \\\n");
-  fprintf(stderr, "          -w -f <filename> -c <chunk size> <server>\n");
+  fprintf(stderr, "          -n -w -f <filename> -c <chunk size> <server>\n");
   fprintf(stderr, "\t-l means logon\n");
   fprintf(stderr, "\t-v means verbose\n");
   fprintf(stderr, "\t-u <username> provides the username for logon\n");
@@ -70,6 +71,7 @@ void usage()
   fprintf(stderr, "\t-s <service> provides the service to use\n");
   fprintf(stderr, "\t-f <filename> provides the file name to use\n");
   fprintf(stderr, "\t-c <chunk size> sets the chunk size\n");
+  fprintf(stderr, "\t-n means set the TCP_NODELAY socket option\n");
   fprintf(stderr, "\t<server> provides the server to connect to.\n");
 }
 
@@ -201,9 +203,13 @@ main(int argc, char* argv[])
 
   /* Parse the parameters */
 
-  while ((opt = getopt(argc, argv, "lvwf:p:u:s:r:c:")) != EOF) {
+  while ((opt = getopt(argc, argv, "lnvwf:p:u:s:r:c:")) != EOF) {
 
     switch (opt) {
+    case 'n':
+      tcp_nodelay = TRUE;
+      break;
+
     case 'c':
       write_chunk_size = atoi(optarg);
       break;
@@ -322,6 +328,9 @@ main(int argc, char* argv[])
   if (verbose == TRUE)
     fprintf(stderr, "Now we connect to service: %s\n", file_service);
 
+  if (tcp_nodelay == TRUE) 
+    SMBlib_Set_Sock_NoDelay(con, TRUE);
+
   tree = SMB_TreeConnect(con, NULL, file_service, "", "A:");
 
   if (tree == NULL) { /* We failed, print an error message and exit */
