@@ -288,11 +288,11 @@ int RFCNB_Hangup(struct RFCNB_Con *con_Handle)
 
 /* Set TCP_NODELAY on the socket                                          */
 
-int RFCNB_Set_Sock_Delay(struct RFCNB_Con *con_Handle, BOOL yn)
+int RFCNB_Set_Sock_NoDelay(struct RFCNB_Con *con_Handle, BOOL yn)
 
 {
 
-  return(setsockopt(con_Handle -> fd, IPPROTO_IP, TCP_NODELAY, 
+  return(setsockopt(con_Handle -> fd, IPPROTO_TCP, TCP_NODELAY, 
 		    (char *)&yn, sizeof(yn)));
 
 }
